These files are used for testing the midi package
=================================================


A minimal working midifile. Plays a one bar "middle C" at 120 bpm. The absolute simplest file I could get to play in midi devices.

    minimal.mid


A simple type 0 midi file exported from cubase.

    cubase-minimal-type0.mid


A simple type 1 midi file exported from cubase.

    cubase-minimal-type1.mid


All 128 midi notes in 1/16 exported from Ableton Live

    ableton-glissando.mid


A single note, 1 bar long. Exported from Ableton Live.

    ableton-minimal-1note.mid

